@@ -6,17 +6,17 @@
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Library General Public License for more details.
 #
-# You should have received a copy of the GNU Library General 
-# Public License along with this library; if not, write to the 
-# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+# You should have received a copy of the GNU Library General
+# Public License along with this library; if not, write to the
+# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
 # Copyrights (C)
-# for this R-port: 
-#   1999 - 2007, Diethelm Wuertz, GPL
+# for this R-port:
+#   1999 - 2008, Diethelm Wuertz, Rmetrics Foundation, GPL
 #   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
 #   info@rmetrics.org
 #   www.rmetrics.org
@@ -30,27 +30,26 @@
 ################################################################################
 
 
-.First.lib =  
+.First.lib =
 function(lib, pkg)
-{   
+{
     # Startup Mesage and Desription:
     MSG <- if(getRversion() >= "2.5") packageStartupMessage else message
     dsc <- packageDescription(pkg)
-    if(interactive() || getOption("verbose")) { 
+    if(interactive() || getOption("verbose")) {
         # not in test scripts
-        MSG(sprintf("\nPackage %s (%s) loaded.\n%s\n",
-            pkg, dsc$Version, dsc$Title),
-            "Rmetrics, (C) 1999-2007, Diethelm Wuertz, GPL\n")
+        MSG(sprintf("Rmetrics Package %s (%s) loaded.", pkg, dsc$Version))
     }
 
     # Load dll:
-    # library.dynam("fExtremes", pkg, lib) 
+    # library.dynam("fExtremes", pkg, lib)
 }
 
-
 if(!exists("Sys.setenv", mode = "function")) # pre R-2.5.0, use "old form"
     Sys.setenv <- Sys.putenv
 
 
+
+
 ################################################################################
 
